#
# spec file for package libskk
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%define real_version 1.0.3
Name:           libskk
# Note this is 1.0.2 release version
# Some package maintainer once specified wrong version number
# so we have to keep 1.2.0
Version:        1.2.0+git20171110+%{real_version}
Release:        3.2
Summary:        A statistical language model based Japanese input method engine
License:        GPL-3.0-or-later
Group:          System/I18n/Japanese
URL:            https://github.com/ueno/libskk
Source0:        %{name}-%{real_version}.tar.xz
Source1:        %{name}-%{real_version}.tar.xz.sig
Source99:       baselibs.conf
Patch0:         libskk-typlib-dependencies.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  sqlite3-devel
BuildRequires:  vala-devel >= 0.14
BuildRequires:  xz
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)

%description
SKK is a statistical language model based Japanese input method engine.
to model the Japanese language, it use a backoff bigram and trigram

%package -n %{name}%{sover}
Summary:        A statistical language model based Japanese input method engine
Group:          System/Libraries
Requires:       skkdic
Requires:       skkdic-extra

%description -n %{name}%{sover}
SKK is a statistical language model based Japanese input method engine.
to model the Japanese language, it use a backoff bigram and trigram

This package provides GObject-based library to deal with Japanese
kana-to-kanji conversion method.

%package -n typelib-1_0-Skk-1_0
Summary:        Introspection bindings for libskk, a Japanese IME
Group:          System/I18n/Japanese
Requires:       girepository-1_0

%description -n typelib-1_0-Skk-1_0
SKK is a statistical language model based Japanese input method engine.
to model the Japanese language, it use a backoff bigram and trigram

This package provides the introspection bindings for the libskk library.

%package -n libskk-devel
Summary:        Development Files for libskk
Group:          Development/Libraries/Other
Requires:       %{name}%{sover} = %{version}

%description -n libskk-devel
SKK is a statistical language model based Japanese input method engine.
to model the Japanese language, it use a backoff bigram and trigram

This package provides C/Vala headers for the libskk library.

%prep
%autosetup -p1 -n %{name}-%{real_version}

%build
autoreconf -f
%configure --disable-static \
           --enable-introspection=yes
%make_build

%install
%make_install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%find_lang %{name}

%fdupes %{buildroot}/%{_prefix}

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover} -f %{name}.lang
%license COPYING
%doc README NEWS
%{_mandir}/man1/skk.1%{?ext_man}
%{_bindir}/skk
%{_libdir}/%{name}.so.*
%{_datadir}/%{name}

%files -n typelib-1_0-Skk-1_0
%{_libdir}/girepository-1.0/Skk-1.0.typelib

%files -n libskk-devel
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/libskk.pc
%{_datadir}/gir-1.0/Skk-1.0.gir
%{_datadir}/vala/vapi/skk-1.0.deps
%{_datadir}/vala/vapi/skk-1.0.vapi

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Oct  7 2021 Matej Cepl <mcepl@suse.com>
- Don't depend on Python 2.
* Thu Mar  8 2018 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use
- Update summaries
* Thu Mar  8 2018 ftake@geeko.jp
- Update to 1.0.3 (1.2.0+git20171110+1.0.3)
  + Fix hiragana to katakana conversion in abbrev mode [#41]
  + Make "commit-unhandled" actually commit in abbrev mode [#39]
  + Avoid redundant dictionary lookup in non-numeric conversion
    cases [#36]
  + Fix KZIK rules [#35, #37]
  + Add command for sticky-shift [#32]
  + Don't crash when a rule has no default metadata [#31]
  + Bind C-j to go back to hiragana in AZIK latin [#30]
  + Build fixes [#42, #43]
* Mon Sep  7 2015 dimstar@opensuse.org
- Add libskk-typlib-dependencies.patch: Fix dependency between
  Skk.typelib and the library.
- Move autogen.sh to build phase, where it belongs.
* Tue Aug 25 2015 opensuse-packaging@opensuse.org
- Update to version 1.2.0+git20150413.be6e20b:
  + Issue #33. Fix initial state of okuri ari recursive edit.
  + Add test for Issue #33
  + Dictionary switch just needs one press (two before), but if
    there's number two press is still needed.
  + rules: inherit KZIK keymap from the default keymap
  + Inherit default/{latin,wide-latin} (KZIK)
* Wed Oct 15 2014 hillwood@linuxfans.org
- Update to 1.0.2
  * Migrate to libgee 0.8 from 0.6.
  * rules: new ACT09 rule contributed by Naoki Mizuno.
  * Consume key event for "commit" command.
    Use "commit-unhandled" for the previous behavior.
  * Comsume C-j in abbrev mode.
* Sat Oct 26 2013 i@marguerite.su
- add Requires: skkdic and skkdic-extra
- without dictionaries, this library is actually useless
* Wed Oct  9 2013 hillwood@linuxfans.org
- disable introspection
* Thu Sep 26 2013 i@marguerite.su
- update version 1.0.1
  * Cancel okuri-ari conversion only if there is no candidate (Issue#23).
  * Allow clients to populate lookup table before setting cursor pos
  (ibus-skk Issue#51).
  * rules: inherit AZIK keymap from the default keymap (Issue#22).
  * Don't use type-punning when converting bytes to uint32 (Issue#20).
* Wed Sep 26 2012 hillwood@linuxfans.org
- fix Requires error for typelib-1_0-Skk-1_0
* Mon Sep 24 2012 cfarrell@suse.com
- license update: GPL-3.0+
  See COPYING
* Tue Sep 18 2012 hillwood@linuxfans.org
- Initial package 1.0.0.
  * Make sure to create parent directory of user-dict (Debian bug#685745).
  * Clear output and preedit on context reset.
  * Fix header include in tests (Issue#19).
